"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }var _logbase = require('../../common/log/log-base');
var _logcolors = require('../../common/log/log-colors');
var _logfilter = require('../../common/log/log-filter');
var _time = require('../../common/time');
var _logcolors3 = require('./log-colors');
function LoggerBrowserHandler(opt = {}) {
  const styleFont = 'font-family: "JetBrains Mono", Menlo; font-size: 11px;';
  const styleDefault = `${styleFont}`;
  const styleBold = `font-weight: 600; ${styleFont}`;
  const useColors = _logcolors3.browserSupportsColors.call(void 0, );
  const namespaces = {};
  const startTime = _time.getTimestamp.call(void 0, );
  const {
    filter = void 0,
    level = void 0,
    colors = true,
    // levelHelper = false,
    // nameBrackets = true,
    padding = 16,
    time = true
  } = opt;
  const matchesNamespace = _logfilter.useNamespaceFilter.call(void 0, filter);
  const matchesLevel = _logfilter.useLevelFilter.call(void 0, level);
  return (msg) => {
    if (!matchesLevel(msg.level))
      return;
    if (!matchesNamespace(msg.name))
      return;
    const timeDiffString = time ? `+${_time.formatMilliseconds.call(void 0, _time.getTimestamp.call(void 0, ) - startTime)}` : "";
    let name = msg.name || "";
    let ninfo = namespaces[name || ""];
    if (ninfo == null) {
      ninfo = {
        color: _logcolors.browserSelectColorByName.call(void 0, name)
        // time: timeNow
      };
      namespaces[name] = ninfo;
    }
    let args;
    if (padding > 0)
      name = name.padEnd(16, " ");
    if (colors && useColors) {
      args = [`%c${name}%c 	%s %c${timeDiffString}`];
      args.push(`color:${ninfo.color}; ${styleBold}`);
      args.push(styleDefault);
      args.push(_nullishCoalesce(_optionalChain([msg, 'access', _ => _.messages, 'optionalAccess', _2 => _2[0]]), () => ( "")));
      args.push(`color:${ninfo.color};`);
      args.push(...msg.messages.slice(1));
    } else {
      args = [name, ...msg.messages, `+${timeDiffString}`];
    }
    args = args.map((arg) => {
      if (arg instanceof Uint8Array)
        return `<Uint8Array size=${arg.length}>`;
      return arg;
    });
    switch (msg.level) {
      case _logbase.LogLevelInfo:
        if (opt.levelHelper)
          args[0] = `I|*   ${args[0]}`;
        console.info(...args);
        break;
      case _logbase.LogLevelWarn:
        if (opt.levelHelper)
          args[0] = `W|**  ${args[0]}`;
        console.warn(...args);
        break;
      case _logbase.LogLevelError:
        if (opt.levelHelper)
          args[0] = `E|*** ${args[0]}`;
        console.error(...args);
        break;
      default:
        if (opt.levelHelper)
          args[0] = `D|    ${args[0]}`;
        console.debug(...args);
        break;
    }
  };
}


exports.LoggerBrowserHandler = LoggerBrowserHandler;
//# sourceMappingURL=log-browser.cjs.map