"use strict";Object.defineProperty(exports, "__esModule", {value: true});var _assert = require('../assert');
var _bin = require('../data/bin');
var _encoding = require('./lib0/encoding');
var _decoding = require('./lib0/decoding');
class BinaryEncoder {
  async encode(data) {
    const dataEncoder = _encoding.createEncoder.call(void 0, );
    _encoding.writeAny.call(void 0, dataEncoder, data);
    return _encoding.encodeToUint8Array.call(void 0, dataEncoder);
  }
  async decode(data) {
    return _decoding.readAny.call(void 0, _decoding.createDecoder.call(void 0, _bin.toUint8Array.call(void 0, data)));
  }
}
function encodeJson(data) {
  const dataEncoder = _encoding.createEncoder.call(void 0, );
  _encoding.writeAny.call(void 0, dataEncoder, data);
  return _encoding.encodeToUint8Array.call(void 0, dataEncoder);
}
function decodeJson(data) {
  return _decoding.readAny.call(void 0, _decoding.createDecoder.call(void 0, _bin.toUint8Array.call(void 0, data)));
}
function createBinaryStreamEncoder(initialData) {
  const dataEncoder = _encoding.createEncoder.call(void 0, );
  if (initialData != null)
    _encoding.writeUint8Array.call(void 0, dataEncoder, _bin.toUint8Array.call(void 0, initialData));
  return {
    /** Just writes the bytes. Length is not stored! */
    writeBytes: (data, expectedLength) => {
      const bin = _bin.toUint8Array.call(void 0, data);
      _assert.assertCondition.call(void 0, !(expectedLength != null && bin.length !== expectedLength), `Expected ${expectedLength} bytes, got ${bin.length}`);
      _encoding.writeUint8Array.call(void 0, dataEncoder, bin);
    },
    writeBytesVar: (data) => _encoding.writeVarUint8Array.call(void 0, dataEncoder, _bin.toUint8Array.call(void 0, data)),
    writeUintVar: (data) => _encoding.writeVarUint.call(void 0, dataEncoder, data),
    writeUint8: (data) => _encoding.writeUint8.call(void 0, dataEncoder, data),
    writeUint16: (data) => _encoding.writeUint16.call(void 0, dataEncoder, data),
    writeUint32: (data) => _encoding.writeUint32.call(void 0, dataEncoder, data),
    writeIntVar: (data) => _encoding.writeVarInt.call(void 0, dataEncoder, data),
    writeFloat: (data) => _encoding.writeFloat32.call(void 0, dataEncoder, data),
    writeStringVar: (data) => _encoding.writeVarString.call(void 0, dataEncoder, data),
    write: (data) => _encoding.writeAny.call(void 0, dataEncoder, data),
    getUint8Array: () => _encoding.encodeToUint8Array.call(void 0, dataEncoder),
    getLength: () => _encoding.length.call(void 0, dataEncoder)
  };
}
function createBinaryStreamDecoder(data) {
  const dataDecoder = _decoding.createDecoder.call(void 0, _bin.toUint8Array.call(void 0, data));
  return {
    readBytes: (len) => _decoding.readUint8Array.call(void 0, dataDecoder, len),
    readBytesVar: () => _decoding.readVarUint8Array.call(void 0, dataDecoder),
    readUintVar: () => _decoding.readVarUint.call(void 0, dataDecoder),
    readUint8: () => _decoding.readUint8.call(void 0, dataDecoder),
    readUint16: () => _decoding.readUint16.call(void 0, dataDecoder),
    readUint32: () => _decoding.readUint32.call(void 0, dataDecoder),
    readIntVar: () => _decoding.readVarInt.call(void 0, dataDecoder),
    readFloat: () => _decoding.readFloat32.call(void 0, dataDecoder),
    readStringVar: () => _decoding.readVarString.call(void 0, dataDecoder),
    read: () => _decoding.readAny.call(void 0, dataDecoder),
    getOffset: () => dataDecoder.pos || 0
  };
}
function bitfield(bitfield2 = 0) {
  return {
    setBit: (bit, value = true) => value ? bitfield2 |= 1 << bit : bitfield2 &= ~(1 << bit),
    unsetBit: (bit) => bitfield2 &= 1 << bit,
    toggleBit: (bit) => bitfield2 ^= 1 << bit,
    getBit: (bit) => (bitfield2 & 1 << bit) !== 0,
    getValue: () => bitfield2
  };
}
async function blobToArrayBuffer(blob) {
  return await blob.arrayBuffer();
}
async function blobToUint8Array(blob) {
  const buffer = await blobToArrayBuffer(blob);
  if (buffer != null)
    return _bin.toUint8Array.call(void 0, buffer);
}









exports.BinaryEncoder = BinaryEncoder; exports.bitfield = bitfield; exports.blobToArrayBuffer = blobToArrayBuffer; exports.blobToUint8Array = blobToUint8Array; exports.createBinaryStreamDecoder = createBinaryStreamDecoder; exports.createBinaryStreamEncoder = createBinaryStreamEncoder; exports.decodeJson = decodeJson; exports.encodeJson = encodeJson;
//# sourceMappingURL=index.cjs.map