"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }var _binary = require('./binary');
var _create = require('./create');
var _string = require('./string');
class Encoder {
  constructor() {
    this.cpos = 0;
    this.cbuf = new Uint8Array(100);
    this.bufs = [];
  }
}
function createEncoder() {
  return new Encoder();
}
function length(encoder) {
  let len = encoder.cpos;
  for (let i = 0; i < encoder.bufs.length; i++)
    len += encoder.bufs[i].length;
  return len;
}
function encodeToUint8Array(encoder) {
  const uint8arr = new Uint8Array(length(encoder));
  let curPos = 0;
  for (let i = 0; i < encoder.bufs.length; i++) {
    const d = encoder.bufs[i];
    uint8arr.set(d, curPos);
    curPos += d.length;
  }
  uint8arr.set(_create.createUint8ArrayViewFromArrayBuffer.call(void 0, encoder.cbuf.buffer, 0, encoder.cpos), curPos);
  return uint8arr;
}
function verifyLen(encoder, len) {
  const bufferLen = encoder.cbuf.length;
  if (bufferLen - encoder.cpos < len) {
    encoder.bufs.push(_create.createUint8ArrayViewFromArrayBuffer.call(void 0, encoder.cbuf.buffer, 0, encoder.cpos));
    encoder.cbuf = new Uint8Array(Math.max(bufferLen, len) * 2);
    encoder.cpos = 0;
  }
}
function write(encoder, num) {
  const bufferLen = encoder.cbuf.length;
  if (encoder.cpos === bufferLen) {
    encoder.bufs.push(encoder.cbuf);
    encoder.cbuf = new Uint8Array(bufferLen * 2);
    encoder.cpos = 0;
  }
  encoder.cbuf[encoder.cpos++] = num;
}
function set(encoder, pos, num) {
  let buffer = null;
  for (let i = 0; i < encoder.bufs.length && buffer === null; i++) {
    const b = encoder.bufs[i];
    if (pos < b.length)
      buffer = b;
    else
      pos -= b.length;
  }
  if (buffer === null) {
    buffer = encoder.cbuf;
  }
  buffer[pos] = num;
}
const writeUint8 = write;
const setUint8 = set;
function writeUint16(encoder, num) {
  write(encoder, num & _binary.BITS8);
  write(encoder, num >>> 8 & _binary.BITS8);
}
function setUint16(encoder, pos, num) {
  set(encoder, pos, num & _binary.BITS8);
  set(encoder, pos + 1, num >>> 8 & _binary.BITS8);
}
function writeUint32(encoder, num) {
  for (let i = 0; i < 4; i++) {
    write(encoder, num & _binary.BITS8);
    num >>>= 8;
  }
}
function writeUint32BigEndian(encoder, num) {
  for (let i = 3; i >= 0; i--)
    write(encoder, num >>> 8 * i & _binary.BITS8);
}
function setUint32(encoder, pos, num) {
  for (let i = 0; i < 4; i++) {
    set(encoder, pos + i, num & _binary.BITS8);
    num >>>= 8;
  }
}
function writeVarUint(encoder, num) {
  while (num > _binary.BITS7) {
    write(encoder, _binary.BIT8 | _binary.BITS7 & num);
    num = Math.floor(num / 128);
  }
  write(encoder, _binary.BITS7 & num);
}
function isNegativeZero(n) {
  return n !== 0 ? n < 0 : 1 / n < 0;
}
function writeVarInt(encoder, num) {
  const isNegative = isNegativeZero(num);
  if (isNegative)
    num = -num;
  write(encoder, (num > _binary.BITS6 ? _binary.BIT8 : 0) | (isNegative ? _binary.BIT7 : 0) | _binary.BITS6 & num);
  num = Math.floor(num / 64);
  while (num > 0) {
    write(encoder, (num > _binary.BITS7 ? _binary.BIT8 : 0) | _binary.BITS7 & num);
    num = Math.floor(num / 128);
  }
}
function writeUint8Array(encoder, uint8Array) {
  const bufferLen = encoder.cbuf.length;
  const cpos = encoder.cpos;
  const leftCopyLen = Math.min(bufferLen - cpos, uint8Array.length);
  const rightCopyLen = uint8Array.length - leftCopyLen;
  encoder.cbuf.set(uint8Array.subarray(0, leftCopyLen), cpos);
  encoder.cpos += leftCopyLen;
  if (rightCopyLen > 0) {
    encoder.bufs.push(encoder.cbuf);
    encoder.cbuf = new Uint8Array(Math.max(bufferLen * 2, rightCopyLen));
    encoder.cbuf.set(uint8Array.subarray(leftCopyLen));
    encoder.cpos = rightCopyLen;
  }
}
function writeVarUint8Array(encoder, uint8Array) {
  writeVarUint(encoder, uint8Array.byteLength);
  writeUint8Array(encoder, uint8Array);
}
let _strBuffer;
let _maxStrBSize;
function _writeVarStringNative(encoder, str) {
  if (_strBuffer == null) {
    _strBuffer = new Uint8Array(3e4);
    _maxStrBSize = _strBuffer.length / 3;
  }
  if (str.length < _maxStrBSize) {
    const written = _string.getUtf8TextEncoder.call(void 0, ).encodeInto(str, _strBuffer).written || 0;
    writeVarUint(encoder, written);
    for (let i = 0; i < written; i++)
      write(encoder, _strBuffer[i]);
  } else {
    writeVarUint8Array(encoder, _string.encodeUtf8.call(void 0, str));
  }
}
function _writeVarStringPolyfill(encoder, str) {
  const encodedString = unescape(encodeURIComponent(str));
  const len = encodedString.length;
  writeVarUint(encoder, len);
  for (let i = 0; i < len; i++)
    write(encoder, encodedString.codePointAt(i));
}
function writeVarString(encoder, str) {
  return _optionalChain([_string.getUtf8TextEncoder.call(void 0, ), 'optionalAccess', _ => _.encodeInto]) ? _writeVarStringNative(encoder, str) : _writeVarStringPolyfill(encoder, str);
}
function writeBinaryEncoder(encoder, append) {
  return writeUint8Array(encoder, encodeToUint8Array(append));
}
function writeOnDataView(encoder, len) {
  verifyLen(encoder, len);
  const dview = new DataView(encoder.cbuf.buffer, encoder.cpos, len);
  encoder.cpos += len;
  return dview;
}
function writeFloat32(encoder, num) {
  return writeOnDataView(encoder, 4).setFloat32(0, num, false);
}
function writeFloat64(encoder, num) {
  return writeOnDataView(encoder, 8).setFloat64(0, num, false);
}
function writeBigInt64(encoder, num) {
  return writeOnDataView(encoder, 8).setBigInt64(0, num, false);
}
function writeBigUint64(encoder, num) {
  return writeOnDataView(encoder, 8).setBigUint64(0, num, false);
}
let floatTestBed;
function isFloat32(num) {
  if (floatTestBed == null)
    floatTestBed = new DataView(new ArrayBuffer(4));
  floatTestBed.setFloat32(0, num);
  return floatTestBed.getFloat32(0) === num;
}
function writeAny(encoder, data) {
  switch (typeof data) {
    case "string":
      write(encoder, 119);
      writeVarString(encoder, data);
      break;
    case "number":
      if (Number.isInteger(data) && Math.abs(data) <= _binary.BITS31) {
        write(encoder, 125);
        writeVarInt(encoder, data);
      } else if (isFloat32(data)) {
        write(encoder, 124);
        writeFloat32(encoder, data);
      } else {
        write(encoder, 123);
        writeFloat64(encoder, data);
      }
      break;
    case "bigint":
      write(encoder, 122);
      writeBigInt64(encoder, data);
      break;
    case "object":
      if (data === null) {
        write(encoder, 126);
      } else if (Array.isArray(data)) {
        write(encoder, 117);
        writeVarUint(encoder, data.length);
        for (let i = 0; i < data.length; i++)
          writeAny(encoder, data[i]);
      } else if (data instanceof Uint8Array) {
        write(encoder, 116);
        writeVarUint8Array(encoder, data);
      } else {
        write(encoder, 118);
        const keys = Object.keys(data);
        writeVarUint(encoder, keys.length);
        for (let i = 0; i < keys.length; i++) {
          const key = keys[i];
          writeVarString(encoder, key);
          writeAny(encoder, data[key]);
        }
      }
      break;
    case "boolean":
      write(encoder, data ? 120 : 121);
      break;
    default:
      write(encoder, 127);
  }
}




























exports.Encoder = Encoder; exports.createEncoder = createEncoder; exports.encodeToUint8Array = encodeToUint8Array; exports.isNegativeZero = isNegativeZero; exports.length = length; exports.set = set; exports.setUint16 = setUint16; exports.setUint32 = setUint32; exports.setUint8 = setUint8; exports.verifyLen = verifyLen; exports.write = write; exports.writeAny = writeAny; exports.writeBigInt64 = writeBigInt64; exports.writeBigUint64 = writeBigUint64; exports.writeBinaryEncoder = writeBinaryEncoder; exports.writeFloat32 = writeFloat32; exports.writeFloat64 = writeFloat64; exports.writeOnDataView = writeOnDataView; exports.writeUint16 = writeUint16; exports.writeUint32 = writeUint32; exports.writeUint32BigEndian = writeUint32BigEndian; exports.writeUint8 = writeUint8; exports.writeUint8Array = writeUint8Array; exports.writeVarInt = writeVarInt; exports.writeVarString = writeVarString; exports.writeVarUint = writeVarUint; exports.writeVarUint8Array = writeVarUint8Array;
//# sourceMappingURL=encoding.cjs.map