"use strict"; function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }





var _crypto = require('./crypto');
var _bin = require('./data/bin');
var _ = require('.');
const log = _.DefaultLogger.call(void 0, "crypto.spec");
describe("crypto", () => {
  it("should not have collisions", () => {
    expect(_bin.equalBinary.call(void 0, new Uint8Array(2), new Uint8Array([0, 0]))).toBe(true);
    const list = Array.apply(null, Array(100)).map(
      () => _crypto.randomUint8Array.call(void 0, 8)
    );
    let id;
    while (id = list.pop()) {
      expect(_bin.equalBinary.call(void 0, id, new Uint8Array([0, 0, 0, 0, 0, 0, 0, 0]))).toBe(
        false
      );
      expect(_optionalChain([id, 'optionalAccess', _3 => _3.length])).toBe(8);
      expect(list).not.toContain(id);
    }
  });
  it("should digest", async () => {
    expect(_bin.toHex.call(void 0, await _crypto.digest.call(void 0, "abc"))).toBe(
      "ba7816bf8f01cfea414140de5dae2223b00361a396177a9cb410ff61f20015ad"
    );
    expect(await _crypto.digest.call(void 0, new Uint8Array([1, 2, 3]))).toMatchInlineSnapshot(`
Uint8Array [
  3,
  144,
  88,
  198,
  242,
  192,
  203,
  73,
  44,
  83,
  59,
  10,
  77,
  20,
  239,
  119,
  204,
  15,
  120,
  171,
  204,
  206,
  213,
  40,
  125,
  132,
  161,
  162,
  1,
  28,
  251,
  129,
]
`);
  });
  it("should raw crypt", async () => {
    const key = await _crypto.deriveKeyPbkdf2.call(void 0, new Uint8Array([1, 2, 3]), {
      salt: new Uint8Array([1, 2, 3])
    });
    const sample = new Uint8Array([9, 8, 7, 6, 5, 4, 3, 2, 1, 0]);
    const cipher = await _crypto.encrypt.call(void 0, sample, key);
    const bin = await _crypto.decrypt.call(void 0, cipher, key);
    expect(_bin.equalBinary.call(void 0, sample, bin)).toBe(true);
    const binFix = await _crypto.decrypt.call(void 0, 
      new Uint8Array([
        1,
        1,
        27,
        108,
        252,
        31,
        238,
        192,
        61,
        168,
        45,
        29,
        128,
        212,
        215,
        222,
        205,
        105,
        178,
        193,
        150,
        36,
        24,
        216,
        180,
        75,
        168,
        133,
        37,
        25,
        124,
        137,
        221,
        103,
        214,
        97,
        218,
        232,
        248,
        93
      ]),
      key
    );
    expect(binFix).toEqual(sample);
  });
});
//# sourceMappingURL=crypto.spec.cjs.map