import {
  decrypt,
  deriveKeyPbkdf2,
  digest,
  encrypt,
  randomUint8Array
} from "./crypto";
import { equalBinary, toHex } from "./data/bin";
import { DefaultLogger } from ".";
const log = DefaultLogger("crypto.spec");
describe("crypto", () => {
  it("should not have collisions", () => {
    expect(equalBinary(new Uint8Array(2), new Uint8Array([0, 0]))).toBe(true);
    const list = Array.apply(null, Array(100)).map(
      () => randomUint8Array(8)
    );
    let id;
    while (id = list.pop()) {
      expect(equalBinary(id, new Uint8Array([0, 0, 0, 0, 0, 0, 0, 0]))).toBe(
        false
      );
      expect(id?.length).toBe(8);
      expect(list).not.toContain(id);
    }
  });
  it("should digest", async () => {
    expect(toHex(await digest("abc"))).toBe(
      "ba7816bf8f01cfea414140de5dae2223b00361a396177a9cb410ff61f20015ad"
    );
    expect(await digest(new Uint8Array([1, 2, 3]))).toMatchInlineSnapshot(`
Uint8Array [
  3,
  144,
  88,
  198,
  242,
  192,
  203,
  73,
  44,
  83,
  59,
  10,
  77,
  20,
  239,
  119,
  204,
  15,
  120,
  171,
  204,
  206,
  213,
  40,
  125,
  132,
  161,
  162,
  1,
  28,
  251,
  129,
]
`);
  });
  it("should raw crypt", async () => {
    const key = await deriveKeyPbkdf2(new Uint8Array([1, 2, 3]), {
      salt: new Uint8Array([1, 2, 3])
    });
    const sample = new Uint8Array([9, 8, 7, 6, 5, 4, 3, 2, 1, 0]);
    const cipher = await encrypt(sample, key);
    const bin = await decrypt(cipher, key);
    expect(equalBinary(sample, bin)).toBe(true);
    const binFix = await decrypt(
      new Uint8Array([
        1,
        1,
        27,
        108,
        252,
        31,
        238,
        192,
        61,
        168,
        45,
        29,
        128,
        212,
        215,
        222,
        205,
        105,
        178,
        193,
        150,
        36,
        24,
        216,
        180,
        75,
        168,
        133,
        37,
        25,
        124,
        137,
        221,
        103,
        214,
        97,
        218,
        232,
        248,
        93
      ]),
      key
    );
    expect(binFix).toEqual(sample);
  });
});
//# sourceMappingURL=crypto.spec.js.map