"use strict";Object.defineProperty(exports, "__esModule", {value: true});var _math = require('./math');
var _orderby = require('./orderby');
function arrayUnique(x) {
  return x.filter((n, index) => x.indexOf(n) === index);
}
function arrayMinus(x, y) {
  return arrayUnique(x.filter((n) => !y.includes(n)));
}
function arrayUnion(...a) {
  return arrayUnique(a.reduce((acc = [], value) => acc.concat(value), []));
}
function arrayFlatten(...list) {
  return list.flat(Number.POSITIVE_INFINITY);
}
function arrayIntersection(x, y) {
  return arrayUnique(x).filter((n) => y.includes(n));
}
function arraySymmetricDifference(x, y) {
  return arrayMinus(arrayUnion(x, y), arrayIntersection(x, y));
}
function arrayRemoveElement(arr, el) {
  if (arr && Array.isArray(arr)) {
    let index;
    while ((index = arr.indexOf(el)) !== -1)
      arr.splice(index, 1);
    return arr;
  }
  return [];
}
function arraySetElement(arr, el) {
  if (!arr.includes(el))
    arr.push(el);
  return arr;
}
function arrayFilterInPlace(array, fn) {
  array.splice(0, array.length, ...array.filter(fn));
  return array;
}
function arrayToggleInPlace(array, el) {
  const index = array.findIndex((e) => e === el);
  if (index >= 0)
    array.splice(index, 1);
  else
    array.push(el);
  return array;
}
function arrayEmptyInPlace(array) {
  array.splice(0, array.length);
  return array;
}
function arraySetArrayInPlace(array, newContent) {
  array.splice(0, array.length, ...newContent);
  return array;
}
function arraySorted(arr, cond = _orderby.cmp) {
  return Array.from(arr).sort(cond);
}
function arraySortedNumbers(arr) {
  return arraySorted(arr, (l, r) => l - r);
}
function arrayIsEqual(array1, array2) {
  return array1.length === array2.length && array1.every((value, index) => value === array2[index]);
}
function arrayShuffleInPlace(array) {
  array.sort(() => _math.getSecureRandomIfPossible.call(void 0, ) > 0.5 ? 1 : -1);
  return array;
}
function arrayShuffle(array) {
  return arrayShuffleInPlace(Array.from(array));
}
function arrayShuffleForce(array) {
  while (array.length > 1) {
    const copy = Array.from(array);
    arrayShuffleInPlace(copy);
    if (!arrayIsEqual(array, copy))
      return copy;
  }
  return array;
}
function arrayRandomElement(array) {
  return array[Math.floor(_math.getSecureRandomIfPossible.call(void 0, ) * array.length)];
}
function arrayMax(...array) {
  return arrayFlatten(array).reduce(
    (acc, value) => acc != null ? value > acc ? value : acc : value,
    void 0
  );
}
function arrayMin(...array) {
  return arrayFlatten(array).reduce(
    (acc, value) => acc != null ? value < acc ? value : acc : value,
    void 0
  );
}
function arraySum(...array) {
  return arrayFlatten(array).reduce((acc, value) => acc + value, 0);
}
function arrayAvg(...array) {
  const flatArray = arrayFlatten(array);
  return flatArray.reduce((acc, value) => acc + value, 0) / flatArray.length;
}
function arrayBatches(array, chunckLength) {
  const chunks = [];
  let i = 0;
  const n = array.length;
  while (i < n)
    chunks.push(array.slice(i, i += chunckLength));
  return chunks;
}
function createArray(length = 0, item) {
  if (length <= 0)
    return [];
  const arr = Array.from({ length });
  for (let i = 0; i < length; i++)
    arr[i] = item instanceof Function ? item(i) : item;
  return arr;
}


























exports.arrayAvg = arrayAvg; exports.arrayBatches = arrayBatches; exports.arrayEmptyInPlace = arrayEmptyInPlace; exports.arrayFilterInPlace = arrayFilterInPlace; exports.arrayFlatten = arrayFlatten; exports.arrayIntersection = arrayIntersection; exports.arrayIsEqual = arrayIsEqual; exports.arrayMax = arrayMax; exports.arrayMin = arrayMin; exports.arrayMinus = arrayMinus; exports.arrayRandomElement = arrayRandomElement; exports.arrayRemoveElement = arrayRemoveElement; exports.arraySetArrayInPlace = arraySetArrayInPlace; exports.arraySetElement = arraySetElement; exports.arrayShuffle = arrayShuffle; exports.arrayShuffleForce = arrayShuffleForce; exports.arrayShuffleInPlace = arrayShuffleInPlace; exports.arraySorted = arraySorted; exports.arraySortedNumbers = arraySortedNumbers; exports.arraySum = arraySum; exports.arraySymmetricDifference = arraySymmetricDifference; exports.arrayToggleInPlace = arrayToggleInPlace; exports.arrayUnion = arrayUnion; exports.arrayUnique = arrayUnique; exports.createArray = createArray;
//# sourceMappingURL=array.cjs.map