import { Uint8ArrayToHexDump } from "./bin";
const TRUE_VALUES_LIST = ["1", "true", "yes", "y", "on"];
function stringToBoolean(value, defaultValue = false) {
  if (value == null || typeof value !== "string")
    return defaultValue;
  return TRUE_VALUES_LIST.includes(String(value).trim().toLowerCase());
}
function stringToInteger(value, defaultValue = 0) {
  if (value == null || typeof value !== "string")
    return defaultValue;
  return Number.parseInt(value.trim(), 10) ?? defaultValue;
}
function stringToFloat(value, defaultValue = 0) {
  if (value == null || typeof value !== "string")
    return defaultValue;
  return Number.parseFloat(value.trim()) ?? defaultValue;
}
function valueToBoolean(value, defaultValue = false) {
  if (value == null)
    return defaultValue;
  if (typeof value === "boolean")
    return value;
  if (typeof value === "number")
    return value !== 0;
  return TRUE_VALUES_LIST.includes(String(value).trim().toLowerCase());
}
function valueToInteger(value, defaultValue = 0) {
  if (value == null)
    return defaultValue;
  if (typeof value === "boolean")
    return value ? 1 : 0;
  if (typeof value === "number")
    return Math.floor(value);
  return Number.parseInt(String(value).trim(), 10) ?? defaultValue;
}
function valueToFloat(value, defaultValue = 0) {
  if (value == null)
    return defaultValue;
  if (typeof value === "boolean")
    return value ? 1 : 0;
  if (typeof value === "number")
    return Math.floor(value);
  return Number.parseFloat(String(value).trim()) ?? defaultValue;
}
function valueToString(value, defaultValue = "") {
  if (value == null)
    return defaultValue;
  return String(value) ?? defaultValue;
}
const toFloat = valueToFloat;
const toInt = valueToInteger;
const toString = valueToString;
const toBool = valueToBoolean;
function formatMessages(messages, opt = {}) {
  const { trace = true, pretty = true } = opt;
  return messages.map((obj) => {
    if (obj && typeof obj === "object") {
      if (pretty && (obj instanceof Uint8Array || obj instanceof ArrayBuffer))
        return `
${Uint8ArrayToHexDump(obj)}
`;
      if (obj instanceof Error) {
        if (!trace)
          return `${obj.name || "Error"}: ${obj.message}`;
        return `${obj.name || "Error"}: ${obj.message}
${obj.stack}`;
      }
      try {
        return pretty ? JSON.stringify(obj, null, 2) : JSON.stringify(obj);
      } catch (err) {
      }
    }
    return String(obj);
  });
}
function renderMessages(messages, opt = {}) {
  return formatMessages(messages, opt).join(" ");
}
function fixBrokenUth8String(brokenString) {
  try {
    return decodeURIComponent(escape(brokenString));
  } catch (e) {
  }
  return brokenString;
}
export {
  fixBrokenUth8String,
  formatMessages,
  renderMessages,
  stringToBoolean,
  stringToFloat,
  stringToInteger,
  toBool,
  toFloat,
  toInt,
  toString,
  valueToBoolean,
  valueToFloat,
  valueToInteger,
  valueToString
};
//# sourceMappingURL=convert.js.map