import { isArray, isObject } from "./is";
function objectMap(obj, fn) {
  if (!isObject(obj))
    return {};
  return Object.fromEntries(
    Object.entries(obj).map(([k, v]) => {
      const r = fn(k, v);
      if (isArray(r) && r.length === 2)
        return r;
      return [k, r];
    }).filter((v) => v != null)
  );
}
function objectMergeDisposable(a, b) {
  if (b.dispose && a.dispose) {
    b.dispose.add(a.dispose);
  }
  return Object.assign(a, b);
}
function objectIsEmpty(obj) {
  return Object.keys(obj).length <= 0;
}
function objectPick(obj, ...keys) {
  return Object.fromEntries(keys.filter((key) => key in obj).map((key) => [key, obj[key]]));
}
function objectInclusivePick(obj, ...keys) {
  return Object.fromEntries(keys.map((key) => [key, obj[key]]));
}
function objectOmit(obj, ...keys) {
  return Object.fromEntries(Object.entries(obj).filter(([key]) => !keys.includes(key)));
}
export {
  objectInclusivePick,
  objectIsEmpty,
  objectMap,
  objectMergeDisposable,
  objectOmit,
  objectPick
};
//# sourceMappingURL=object.js.map