"use strict";var _disposedefer = require('../dispose-defer');
var _emitter = require('../msg/emitter');
var _object = require('./object');
describe("object.spec", () => {
  it("should map it", async () => {
    const sample = {
      a: 1,
      b: 2
    };
    expect(_object.objectMap.call(void 0, sample, (k, v) => v + 10)).toMatchInlineSnapshot(`
      Object {
        "a": 11,
        "b": 12,
      }
    `);
    expect(_object.objectMap.call(void 0, sample, (k, v) => [`${k}_${v}`, k])).toMatchInlineSnapshot(`
        Object {
          "a_1": "a",
          "b_2": "b",
        }
      `);
  });
  it("should merge", async () => {
    const emitter = new (0, _emitter.Emitter)();
    const obj = {
      dispose: _disposedefer.useDispose.call(void 0, ),
      f() {
        return 42;
      }
    };
    let x = 1;
    obj.dispose.add(() => x++);
    const m = _object.objectMergeDisposable.call(void 0, emitter, obj);
    expect(m.f()).toBe(42);
    m.on("a", () => x++);
    m.emit("a");
    expect(x).toBe(2);
    await m.dispose();
    expect(x).toBe(3);
  });
  it("should omit and pick", () => {
    const o = { a: 1, b: 2, c: 3, d: 4 };
    expect(_object.objectPick.call(void 0, o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
      }
    `);
    expect(_object.objectOmit.call(void 0, o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "b": 2,
        "d": 4,
      }
    `);
    expect(_object.objectInclusivePick.call(void 0, o, "a", "c", "x")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
        "x": undefined,
      }
    `);
  });
});
//# sourceMappingURL=object.spec.cjs.map