"use strict";








var _rounding = require('./rounding');
describe("currency", () => {
  describe("down", () => {
    it("rounds down with a positive float below half", () => {
      expect(_rounding.roundDown.call(void 0, 1.4)).toBe(1);
    });
    it("rounds down with a negative float below half", () => {
      expect(_rounding.roundDown.call(void 0, -1.4)).toBe(-2);
    });
    it("rounds down with a positive half float", () => {
      expect(_rounding.roundDown.call(void 0, 1.5)).toBe(1);
    });
    it("rounds down with a negative half float", () => {
      expect(_rounding.roundDown.call(void 0, -1.5)).toBe(-2);
    });
    it("rounds down with a positive float above half", () => {
      expect(_rounding.roundDown.call(void 0, 1.6)).toBe(1);
    });
    it("rounds down with a negative float above half", () => {
      expect(_rounding.roundDown.call(void 0, -1.6)).toBe(-2);
    });
  });
  describe("halfAwayFromZero", () => {
    it("rounds down with a positive float below half", () => {
      expect(_rounding.roundHalfAwayFromZero.call(void 0, 1.4)).toBe(1);
    });
    it("rounds up with a negative float below half", () => {
      expect(_rounding.roundHalfAwayFromZero.call(void 0, -1.4)).toBe(-1);
    });
    it("rounds to the nearest integer away from zero with a positive half float", () => {
      expect(_rounding.roundHalfAwayFromZero.call(void 0, 1.5)).toBe(2);
    });
    it("rounds to the nearest integer away from zero with a negative half float", () => {
      expect(_rounding.roundHalfAwayFromZero.call(void 0, -2.5)).toBe(-3);
    });
    it("rounds up with a positive float above half", () => {
      expect(_rounding.roundHalfAwayFromZero.call(void 0, 1.6)).toBe(2);
    });
    it("rounds down with a negative float above half", () => {
      expect(_rounding.roundHalfAwayFromZero.call(void 0, -1.6)).toBe(-2);
    });
  });
  describe("halfDown", () => {
    it("rounds down with a positive float below half", () => {
      expect(_rounding.roundHalfDown.call(void 0, 1.4)).toBe(1);
    });
    it("rounds down with a negative float below half", () => {
      expect(_rounding.roundHalfDown.call(void 0, -1.4)).toBe(-1);
    });
    it("rounds down with a positive half float", () => {
      expect(_rounding.roundHalfDown.call(void 0, 1.5)).toBe(1);
    });
    it("rounds down with a negative half float", () => {
      expect(_rounding.roundHalfDown.call(void 0, -1.5)).toBe(-2);
    });
    it("rounds up with a positive float above half", () => {
      expect(_rounding.roundHalfDown.call(void 0, 1.6)).toBe(2);
    });
    it("rounds down with a negative float above half", () => {
      expect(_rounding.roundHalfDown.call(void 0, -1.6)).toBe(-2);
    });
  });
  describe("halfEven", () => {
    it("rounds down with a positive float below half", () => {
      expect(_rounding.roundHalfEven.call(void 0, 1.4)).toBe(1);
    });
    it("rounds down with a negative float below half", () => {
      expect(_rounding.roundHalfEven.call(void 0, -1.4)).toBe(-1);
    });
    it("rounds to nearest even integer with a positive half float rounding to an even integer", () => {
      expect(_rounding.roundHalfEven.call(void 0, 1.5)).toBe(2);
    });
    it("rounds to nearest even integer with a positive half float rounding to an odd integer", () => {
      expect(_rounding.roundHalfEven.call(void 0, 2.5)).toBe(2);
    });
    it("rounds to nearest even integer with a negative half float", () => {
      expect(_rounding.roundHalfEven.call(void 0, -2.5)).toBe(-2);
    });
    it("rounds up with a positive float above half", () => {
      expect(_rounding.roundHalfEven.call(void 0, 1.6)).toBe(2);
    });
    it("rounds down with a negative float above half", () => {
      expect(_rounding.roundHalfEven.call(void 0, -1.6)).toBe(-2);
    });
  });
  it("rounds down with a positive float below half", () => {
    expect(_rounding.roundHalfOdd.call(void 0, 1.4)).toBe(1);
  });
  it("rounds down with a negative float below half", () => {
    expect(_rounding.roundHalfOdd.call(void 0, -1.4)).toBe(-1);
  });
  it("rounds to nearest odd integer with a positive half float rounding to an even integer", () => {
    expect(_rounding.roundHalfOdd.call(void 0, 1.5)).toBe(1);
  });
  it("rounds to nearest odd integer with a positive half float rounding to an odd integer", () => {
    expect(_rounding.roundHalfOdd.call(void 0, 2.5)).toBe(3);
  });
  it("rounds to nearest odd integer with a negative half float", () => {
    expect(_rounding.roundHalfOdd.call(void 0, -2.5)).toBe(-3);
  });
  it("rounds up with a positive float above half", () => {
    expect(_rounding.roundHalfOdd.call(void 0, 1.6)).toBe(2);
  });
  it("rounds down with a negative float above half", () => {
    expect(_rounding.roundHalfOdd.call(void 0, -1.6)).toBe(-2);
  });
  describe("halfTowardsZero", () => {
    it("rounds down with a positive float below half", () => {
      expect(_rounding.roundHalfTowardsZero.call(void 0, 1.4)).toBe(1);
    });
    it("rounds up with a negative float below half", () => {
      expect(_rounding.roundHalfTowardsZero.call(void 0, -1.4)).toBe(-1);
    });
    it("rounds to the nearest integer towards zero with a positive half float", () => {
      expect(_rounding.roundHalfTowardsZero.call(void 0, 1.5)).toBe(1);
    });
    it("rounds to the nearest integer towards zero with a negative half float", () => {
      expect(_rounding.roundHalfTowardsZero.call(void 0, -2.5)).toBe(-2);
    });
    it("rounds up with a positive float above half", () => {
      expect(_rounding.roundHalfTowardsZero.call(void 0, 1.6)).toBe(2);
    });
    it("rounds down with a negative float above half", () => {
      expect(_rounding.roundHalfTowardsZero.call(void 0, -1.6)).toBe(-2);
    });
  });
  describe("halfUp", () => {
    it("rounds down with a positive float below half", () => {
      expect(_rounding.roundHalfUp.call(void 0, 1.4)).toBe(1);
    });
    it("rounds down with a negative float below half", () => {
      expect(_rounding.roundHalfUp.call(void 0, -1.4)).toBe(-1);
    });
    it("rounds up with a positive half float", () => {
      expect(_rounding.roundHalfUp.call(void 0, 1.5)).toBe(2);
    });
    it("rounds up with a negative half float", () => {
      expect(_rounding.roundHalfUp.call(void 0, -2.5)).toBe(-2);
    });
    it("rounds up with a positive float above half", () => {
      expect(_rounding.roundHalfUp.call(void 0, 1.6)).toBe(2);
    });
    it("rounds down with a negative float above half", () => {
      expect(_rounding.roundHalfUp.call(void 0, -1.6)).toBe(-2);
    });
  });
  describe("up", () => {
    it("rounds up with a positive float below half", () => {
      expect(_rounding.roundUp.call(void 0, 1.4)).toBe(2);
    });
    it("rounds up with a negative float below half", () => {
      expect(_rounding.roundUp.call(void 0, -1.4)).toBe(-1);
    });
    it("rounds up with a positive half float", () => {
      expect(_rounding.roundUp.call(void 0, 1.5)).toBe(2);
    });
    it("rounds up with a negative half float", () => {
      expect(_rounding.roundUp.call(void 0, -1.5)).toBe(-1);
    });
    it("rounds up with a positive float above half", () => {
      expect(_rounding.roundUp.call(void 0, 1.6)).toBe(2);
    });
    it("rounds up with a negative float above half", () => {
      expect(_rounding.roundUp.call(void 0, -1.6)).toBe(-1);
    });
  });
});
//# sourceMappingURL=rounding.spec.cjs.map