import { arrayShuffleForce, arrayShuffleInPlace, last } from "..";
import { useSorted } from "./sorted";
describe("sorted", () => {
  const sorted = useSorted();
  const list = [-0.2, -1e-3, 0, 1e-3, 2];
  const items = list.map((sort, index) => ({ index, sort }));
  it("should add correctly", () => {
    expect(sorted.start(items)).toBeLessThan(list[0]);
    expect(sorted.end(items)).toBeGreaterThan(last(list) || 0);
  });
  it("should sort correctly", () => {
    const shuffledItems = arrayShuffleForce(items);
    expect(shuffledItems.map((el) => el.sort)).not.toEqual(list);
    expect(sorted.items(shuffledItems).map((el) => el.sort)).toEqual(list);
  });
  it("should move correctly", () => {
    let items2 = [];
    for (let i = 0; i < 10; i++) {
      items2.push({
        name: String(i),
        sort: i
      });
    }
    expect(
      sorted.items(items2).map((o) => o.name).join("")
    ).toEqual("0123456789");
    const moveItem = items2[8];
    moveItem.sort = sorted.move(1, 8, items2);
    expect(
      sorted.items(items2).map((o) => o.name).join("")
    ).toEqual("0812345679");
    items2 = sorted.items(items2);
    const moveItem2 = items2[1];
    arrayShuffleInPlace(items2);
    moveItem2.sort = sorted.move(8, 1, items2);
    expect(
      sorted.items(items2).map((o) => o.name).join("")
    ).toEqual("0123456789");
  });
});
//# sourceMappingURL=sorted.spec.js.map