"use strict"; function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }var _log = require('./log');
var _disposedefer = require('./dispose-defer');
var _exec = require('./exec');
const log = _log.DefaultLogger.call(void 0, "dispose-test");
describe("dispose", () => {
  it("should dispose correctly", async () => {
    const disposeCalls = [];
    const dispose = _disposedefer.useDispose.call(void 0, "a");
    const y = dispose.track({
      dispose() {
        disposeCalls.push(1);
      }
    });
    dispose.track(() => {
      disposeCalls.push(2);
    });
    const x = {
      async dispose() {
        disposeCalls.push(3);
      }
    };
    dispose.track(x);
    dispose.track();
    dispose.track(async () => {
      disposeCalls.push(4);
    });
    expect(disposeCalls).toEqual([]);
    expect(dispose.getSize()).toEqual(4);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    _optionalChain([y, 'optionalCall', _ => _()]);
    _optionalChain([y, 'optionalCall', _2 => _2()]);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3, 1]);
    expect(dispose.getSize()).toEqual(2);
    await dispose.dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
    await dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
  });
  it("should be a fancy dispose itself", () => {
    let x = 1;
    class Some {
      constructor() {
        this.dispose = _disposedefer.useDispose.call(void 0, log);
        this.dispose.track(() => {
          x = 2;
        });
      }
    }
    const obj = new Some();
    expect(x).toBe(1);
    obj.dispose();
    expect(x).toBe(2);
  });
  it("should defer lifo", async () => {
    const stack = [];
    const defer = _disposedefer.useDefer.call(void 0, { mode: "lifo" });
    defer.add(() => stack.push("a"));
    defer.add(() => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    defer(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should defer fifo", async () => {
    const stack = [];
    const defer = _disposedefer.useDefer.call(void 0, { mode: "fifo" });
    defer.add(() => stack.push("a"));
    defer.add(async () => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await defer();
    expect(stack).toEqual(["a", "b", "c"]);
  });
  it("should dispose sync", async () => {
    const stack = [];
    const dispose = _disposedefer.useDispose.call(void 0, );
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await dispose(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync 2", async () => {
    const stack = [];
    const dispose = _disposedefer.useDispose.call(void 0, );
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(async () => {
      await _exec.sleep.call(void 0, 1);
      stack.push("c");
    });
    expect(stack).toEqual([]);
    expect(dispose.sync).toThrowError();
  });
});
//# sourceMappingURL=dispose-defer.spec.cjs.map