"use strict";var _promise = require('./promise');
var _queue = require('./queue');
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new (0, _queue.SerialQueue)();
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    (async () => {
      await _promise.sleep.call(void 0, 100);
      list.push("a");
    })();
    (async () => {
      await _promise.sleep.call(void 0, 200);
      list.push("b");
    })();
    (async () => {
      await _promise.sleep.call(void 0, 1);
      list.push("c");
    })();
    await _promise.sleep.call(void 0, 500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new (0, _queue.SerialQueue)();
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _queue.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _queue.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 100);
      list.push("a");
    });
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 200);
      list.push("b");
    });
    queue.enqueue(async () => {
      await _promise.sleep.call(void 0, 1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.cjs.map