"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } }var _logbase = require('./log-base');
var _logconsole = require('./log-console');
var _logfilter = require('./log-filter');
function LoggerContext(_prefix = "") {
  let logHandlers = [_logconsole.LoggerConsoleHandler.call(void 0, )];
  let logCheckNamespace = (_name) => true;
  let logLock = false;
  let logFactory = LoggerBaseFactory;
  let logDebug = false;
  function LoggerBaseFactory(name = "", level) {
    const logLevel = _logfilter.parseLogLevel.call(void 0, _nullishCoalesce(level, () => ( _logbase.LogLevelAll)));
    function defineForLogLevel(fnLevel, fn) {
      if (logLevel <= fnLevel)
        return fn;
      return () => {
      };
    }
    const emit = (msg) => {
      if (logCheckNamespace(name)) {
        for (const handler of logHandlers) {
          if (handler)
            handler(msg);
        }
      }
    };
    const log = defineForLogLevel(_logbase.LogLevelDebug, (...messages) => {
      emit({
        name,
        messages,
        level: _logbase.LogLevelDebug
      });
    });
    log.label = name;
    log.extend = function(prefix) {
      return logFactory(name ? `${name}:${prefix}` : prefix);
    };
    log.debug = defineForLogLevel(_logbase.LogLevelDebug, (...messages) => {
      emit({ name, messages, level: _logbase.LogLevelDebug });
    });
    log.info = defineForLogLevel(_logbase.LogLevelInfo, (...messages) => {
      emit({ name, messages, level: _logbase.LogLevelInfo });
    });
    log.warn = defineForLogLevel(_logbase.LogLevelWarn, (...messages) => {
      emit({ name, messages, level: _logbase.LogLevelWarn });
    });
    log.error = defineForLogLevel(_logbase.LogLevelError, (...messages) => {
      emit({ name, messages, level: _logbase.LogLevelError });
    });
    log.fatal = defineForLogLevel(_logbase.LogLevelFatal, (...messages) => {
      emit({ name, messages, level: _logbase.LogLevelFatal });
      throw new Error(`${messages.map(String).join(" ")}`);
    });
    log.assert = defineForLogLevel(_logbase.LogLevelFatal, (condition, ...args) => {
      if (condition == null || typeof condition === "number" && Number.isNaN(condition) || !condition)
        log.fatal(...args);
    });
    return log;
  }
  function Logger(name = "", level) {
    const log = logFactory(name, level);
    if (logDebug)
      log.debug(`+++ init of logger "${name}" on level "${log.level}".`);
    return log;
  }
  Logger.registerHandler = function(handler) {
    logHandlers.push(handler);
  };
  Logger.setFilter = function(namespaces) {
    logCheckNamespace = _logfilter.useNamespaceFilter.call(void 0, namespaces);
  };
  Logger.setLock = (lock = true) => logLock = lock;
  Logger.setDebug = (debug = true) => logDebug = debug;
  Logger.setHandlers = function(handlers = []) {
    if (logFactory !== LoggerBaseFactory)
      logFactory = LoggerBaseFactory;
    if (logLock)
      return;
    logHandlers = [...handlers].filter((h) => typeof h === "function");
  };
  Logger.level = _logbase.LogLevelAll;
  Logger.setLogLevel = function(level = _logbase.LogLevelAll) {
    if (logLock)
      return;
    Logger.level = level;
  };
  Logger.setFactory = function(factory) {
    if (logLock)
      return;
    logFactory = factory;
  };
  return Logger;
}


exports.LoggerContext = LoggerContext;
//# sourceMappingURL=log-context.cjs.map