"use strict";var _logbase = require('./log-base');
var _logfilter = require('./log-filter');
describe("log-filter", () => {
  it("should match", () => {
    {
      const matches = _logfilter.useNamespaceFilter.call(void 0, "a");
      expect(matches.filter).toBe("a");
      expect(matches.accept).toEqual([/^a/]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(false);
    }
    {
      const matches = _logfilter.useNamespaceFilter.call(void 0, "a*");
      expect(matches.filter).toBe("a*");
      expect(matches.accept).toEqual([/^a.*?/]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(false);
    }
    {
      const matches = _logfilter.useNamespaceFilter.call(void 0, "a*,b*,-c*");
      expect(matches.filter).toBe("a*,b*,-c*");
      expect(matches.accept).toEqual([/^a.*?/, /^b.*?/]);
      expect(matches.reject).toEqual([/^c.*?/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = _logfilter.useNamespaceFilter.call(void 0, "*,-c*");
      expect(matches.filter).toBe("*,-c*");
      expect(matches.accept).toEqual([/^.*?/]);
      expect(matches.reject).toEqual([/^c.*?/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = _logfilter.useNamespaceFilter.call(void 0, "*,-c");
      expect(matches.filter).toBe("*,-c");
      expect(matches.accept).toEqual([/^.*?/]);
      expect(matches.reject).toEqual([/^c/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = _logfilter.useNamespaceFilter.call(void 0, "*");
      expect(matches.filter).toBe("*");
      expect(matches.accept).toEqual([]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("b:c")).toBe(true);
    }
  });
  it("should interprete filter right", () => {
    expect(_logfilter.getNamespaceFilterString.call(void 0, "")).toEqual("");
    expect(_logfilter.getNamespaceFilterString.call(void 0, 0)).toEqual("");
    expect(_logfilter.getNamespaceFilterString.call(void 0, false)).toEqual("");
    expect(_logfilter.getNamespaceFilterString.call(void 0, "false")).toEqual("");
    expect(_logfilter.getNamespaceFilterString.call(void 0, null)).toEqual("");
    expect(_logfilter.getNamespaceFilterString.call(void 0, "*")).toEqual("*");
    expect(_logfilter.getNamespaceFilterString.call(void 0, 1)).toEqual("*");
    expect(_logfilter.getNamespaceFilterString.call(void 0, true)).toEqual("*");
    expect(_logfilter.getNamespaceFilterString.call(void 0, "true")).toEqual("*");
    expect(_logfilter.getNamespaceFilterString.call(void 0, "a:b")).toEqual("a:b");
  });
  it("should filter by level", () => {
    {
      const levelFilter = _logfilter.useLevelFilter.call(void 0, "err");
      expect(levelFilter(_logbase.LogLevelDebug)).toBe(false);
      expect(levelFilter(_logbase.LogLevelWarn)).toBe(false);
      expect(levelFilter(_logbase.LogLevelError)).toBe(true);
    }
    {
      const levelFilter = _logfilter.useLevelFilter.call(void 0, "adfdfds");
      expect(levelFilter(_logbase.LogLevelDebug)).toBe(true);
      expect(levelFilter(_logbase.LogLevelWarn)).toBe(true);
      expect(levelFilter(_logbase.LogLevelError)).toBe(true);
    }
    {
      const levelFilter = _logfilter.useLevelFilter.call(void 0, _logbase.LogLevelWarn);
      expect(levelFilter(_logbase.LogLevelDebug)).toBe(false);
      expect(levelFilter(_logbase.LogLevelWarn)).toBe(true);
      expect(levelFilter(_logbase.LogLevelError)).toBe(true);
    }
  });
  it("should identify log level", () => {
    expect(_logfilter.parseLogLevel.call(void 0, false)).toEqual(_logbase.LogLevelOff);
    expect(_logfilter.parseLogLevel.call(void 0, "info")).toEqual(_logbase.LogLevelInfo);
    expect(_logfilter.parseLogLevel.call(void 0, _logbase.LogLevelError)).toEqual(_logbase.LogLevelError);
    expect(_logfilter.parseLogLevel.call(void 0, true)).toEqual(_logbase.LogLevelAll);
    expect(_logfilter.parseLogLevel.call(void 0, 2)).toEqual(_logbase.LogLevelWarn);
  });
  it("should join strings", () => {
    expect(_logfilter.joinLogStrings.call(void 0, "test")).toEqual(["test"]);
    expect(_logfilter.joinLogStrings.call(void 0, "test", "more", 1, 2, 3)).toEqual(["test more", 1, 2, 3]);
    expect(_logfilter.joinLogStrings.call(void 0, "test", { a: 1 })).toEqual(["test", { a: 1 }]);
    expect(_logfilter.joinLogStrings.call(void 0, "test", "a", "b", true, void 0, null, { a: 1 })).toEqual(["test a", "b", true, void 0, null, { a: 1 }]);
  });
});
//# sourceMappingURL=log-filter.spec.cjs.map