import { decrypt, encrypt } from "../crypto";
import { Uint8ArrayToJson, jsonToUint8Array } from "../data/bin";
class NoopEncoder {
  async encode(data) {
    return data;
  }
  async decode(data) {
    return data;
  }
}
class JsonEncoder {
  async encode(data) {
    return jsonToUint8Array(data);
  }
  async decode(data) {
    return Uint8ArrayToJson(data);
  }
}
class CryptoEncoder {
  constructor(key) {
    this.key = key;
  }
  async encode(data) {
    const plain = jsonToUint8Array(data);
    return await encrypt(plain, this.key);
  }
  async decode(data) {
    const plain = await decrypt(data, this.key);
    return Uint8ArrayToJson(plain);
  }
}
export {
  CryptoEncoder,
  JsonEncoder,
  NoopEncoder
};
//# sourceMappingURL=encoder.js.map