import { deriveKeyPbkdf2, randomUint8Array } from "../crypto";
import { createLocalChannelPair } from "./channel";
import { CryptoEncoder } from "./encoder";
import { useMessageHub } from "./messages";
describe("messages", () => {
  it("should show the magic of proxies ", async () => {
    const p = new Proxy({}, {
      get(_target, _name) {
        return (...args) => {
          return args[0] ?? 0;
        };
      }
    });
    expect(await p.ping(await p.ping(2))).toBe(2);
  });
  it("should do hub thing", async () => {
    const key = await deriveKeyPbkdf2(randomUint8Array(20));
    const encoder = new CryptoEncoder(key);
    const [clientChannel, serverChannel] = createLocalChannelPair();
    const serverHub = useMessageHub({ channel: serverChannel, encoder });
    serverHub.listen({
      async ping(value) {
        expect(value).toBe(2);
        return value;
      }
    });
    serverHub.listen({
      async aping(value) {
        return new Promise((resolve) => setTimeout(() => resolve(value), 500));
      }
    });
    const clientHub = useMessageHub({ channel: clientChannel, encoder });
    const client = clientHub.send();
    const x = await client.aping(1);
    const y = await client.aping("H\xE4llo W\u{1F468}\u200D\u{1F469}\u200D\u{1F467}\u200D\u{1F466}rld");
    expect(x).toBe(1);
    expect(y).toBe("H\xE4llo W\u{1F468}\u200D\u{1F469}\u200D\u{1F467}\u200D\u{1F466}rld");
    await client.ping(2);
  });
});
//# sourceMappingURL=messages.spec.js.map