import { MessageChannel } from "node:worker_threads";
import { decodeJson, encodeJson } from "../bin";
import { useRPC, useRPCHub } from "./rpc";
let bobCount = 0;
const Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
const Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
  it("hub", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
});
//# sourceMappingURL=rpc.spec.js.map