"use strict";Object.defineProperty(exports, "__esModule", {value: true});





var _data = require('./data');
var _url = require('./data/url');
var _log = require('./log');
const defaultOptions = {
  cache: "no-cache",
  redirect: "follow",
  headers: {}
};
function parseBasicAuth(url) {
  const m = /:\/\/([^@]*)@/gi.exec(url);
  if (m && m[1]) {
    const [username, password] = m[1].split(":", 2);
    return {
      url: url.replace(`${m[1]}@`, ""),
      username,
      password
    };
  }
}
async function fetchBasic(url, fetchOptions = {}, fetchFn = fetch) {
  try {
    if (_data.isArray.call(void 0, fetchOptions))
      fetchOptions = _data.deepMerge.call(void 0, {}, ..._data.arrayFlatten.call(void 0, fetchOptions));
    const auth = parseBasicAuth(String(url));
    if (auth) {
      url = auth.url;
      fetchOptions = _data.deepMerge.call(void 0, 
        {},
        fetchOptions,
        fetchOptionsBasicAuth(auth.username, auth.password)
      );
    }
    if (
      // @ts-expect-error headers
      fetchOptions.headers != null && !(fetchOptions.headers instanceof Headers)
    ) {
      fetchOptions.headers = new Headers(fetchOptions.headers);
    }
    const response = await fetchFn(String(url), fetchOptions);
    if (response.status < 400)
      return response;
    const log = _log.DefaultLogger.call(void 0, "zeed:network");
    try {
      log.warn(`Fetch of ${String(url)} returned status=${response.status}. Options:`, fetchOptions);
      log.warn(`Response: ${await response.text()}`);
    } catch (err) {
      log.error("Exception:", err);
    }
  } catch (err) {
    const log = _log.DefaultLogger.call(void 0, "zeed:network");
    log.error("fetchBasic", err);
  }
}
async function fetchJson(url, fetchOptions = {}, fetchFn = fetch) {
  try {
    const res = await fetchBasic(
      url,
      [
        {
          method: "GET",
          headers: {
            Accept: "application/json"
          }
        },
        fetchOptions
      ],
      fetchFn
    );
    if (res)
      return await res.json();
  } catch (err) {
    const log = _log.DefaultLogger.call(void 0, "zeed:network");
    log.error("fetchJSON error:", err);
  }
}
async function fetchText(url, fetchOptions = {}, fetchFn = fetch) {
  try {
    const res = await fetchBasic(
      url,
      [defaultOptions, { method: "GET" }, fetchOptions],
      fetchFn
    );
    if (res)
      return await res.text();
  } catch (err) {
    const log = _log.DefaultLogger.call(void 0, "zeed:network");
    log.error("fetchHTML error:", err);
  }
}
function fetchOptionsFormURLEncoded(data, method = "POST") {
  return {
    method,
    ...defaultOptions,
    headers: {
      "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"
    },
    body: _url.encodeQuery.call(void 0, data)
  };
}
function fetchOptionsJson(data, method = "POST") {
  return {
    method,
    ...defaultOptions,
    headers: {
      "Content-Type": "application/json; charset=utf-8"
      // Accept: "application/json",
    },
    body: _data.jsonStringifySafe.call(void 0, data)
  };
}
function fetchOptionsBasicAuth(username, password) {
  return {
    headers: {
      Authorization: `Basic ${_data.toBase64.call(void 0, `${username}:${password}`)}`
    }
  };
}








exports.fetchBasic = fetchBasic; exports.fetchJson = fetchJson; exports.fetchOptionsBasicAuth = fetchOptionsBasicAuth; exports.fetchOptionsFormURLEncoded = fetchOptionsFormURLEncoded; exports.fetchOptionsJson = fetchOptionsJson; exports.fetchText = fetchText; exports.parseBasicAuth = parseBasicAuth;
//# sourceMappingURL=network.cjs.map