import { randomUint8Array } from "./crypto";
import { fromHex, toHex } from "./data";
import { decodeBase32, decodeBase62, encodeBase32, encodeBase62 } from "./data/basex";
import { getTimestamp } from "./time";
const uuidBytesLength = 16;
function uuidBytes() {
  return randomUint8Array(uuidBytesLength);
}
function uuidB62(bytes = uuidBytes()) {
  return encodeBase62(bytes, 22);
}
function uuidEncodeB62(bytes) {
  return encodeBase62(bytes, 22);
}
function uuidDecodeB62(uuid2) {
  return decodeBase62(uuid2, uuidBytesLength);
}
function uuidB32(bytes = uuidBytes()) {
  return encodeBase32(bytes, 26);
}
function uuidEncodeB32(bytes) {
  return encodeBase32(bytes, 26);
}
function uuidDecodeB32(uuid2) {
  return decodeBase32(uuid2, uuidBytesLength);
}
const pattern = "10000000-1000-4000-8000-100000000000";
const uuidv4 = function() {
  return typeof crypto !== "undefined" && crypto.randomUUID != null ? crypto.randomUUID() : pattern.replace(/[018]/g, (c) => (c ^ randomUint8Array(1)[0] & 15 >> c / 4).toString(16));
};
function uuidEncodeV4(bytes) {
  const id = toHex(bytes);
  return `${id.slice(0, 8)}-${id.slice(8, 12)}-${id.slice(12, 16)}-${id.slice(16)}`;
}
function uuidDecodeV4(uuid2) {
  return fromHex(uuid2.replaceAll("-", ""));
}
const ReferenceDateInMS = 16e11;
function longToByteArray(long) {
  const byteArray = new Uint8Array([0, 0, 0, 0, 0, 0]);
  const bytes = byteArray.length - 1;
  for (let index = 0; index < byteArray.length; index++) {
    const byte = long & 255;
    byteArray[bytes - index] = byte;
    long = (long - byte) / 256;
  }
  return byteArray;
}
function suidBytes() {
  const ms = getTimestamp() - ReferenceDateInMS;
  return new Uint8Array([...longToByteArray(ms), ...randomUint8Array(10)]);
}
function suid() {
  return uuidEncode(suidBytes());
}
function suidDate(id) {
  return suidBytesDate(uuidDecode(id));
}
function suidBytesDate(id) {
  return new Date(
    ReferenceDateInMS + id.slice(0, 6).reduce((acc, byte) => acc * 256 + byte, 0)
  );
}
function uuid32bit() {
  return new Uint32Array(randomUint8Array(4))[0];
}
const mapModes = {
  base62: {
    uuid: uuidB62,
    uuidDecode: uuidDecodeB62,
    uuidEncode: uuidEncodeB62
  },
  base32: {
    uuid: uuidB32,
    uuidDecode: uuidDecodeB32,
    uuidEncode: uuidEncodeB32
  },
  uuidv4: {
    uuid: uuidv4,
    uuidDecode: uuidDecodeV4,
    uuidEncode: uuidEncodeV4
  }
};
let _mode = "base62";
let _sorted = false;
function setUuidDefaultEncoding(mode, sorted = false) {
  _mode = mode;
  _sorted = sorted;
}
function uuid() {
  return mapModes[_mode].uuid(_sorted ? suidBytes() : uuidBytes());
}
function uuidDecode(uuid2) {
  return mapModes[_mode].uuidDecode(uuid2);
}
function uuidEncode(bytes) {
  return mapModes[_mode].uuidEncode(bytes);
}
function uuidIsValid(uuid2) {
  try {
    const bin = uuidDecode(uuid2);
    return bin.length === uuidBytesLength;
  } catch (err) {
  }
  return false;
}
const _unameCounters = {};
function uname(name = "id") {
  if (_unameCounters[name] == null)
    _unameCounters[name] = 0;
  return `${name}-${_unameCounters[name]++}`;
}
let _qid = 0;
function qid() {
  return `id-${_qid++}`;
}
export {
  qid,
  setUuidDefaultEncoding,
  suid,
  suidBytes,
  suidBytesDate,
  suidDate,
  uname,
  uuid,
  uuid32bit,
  uuidB32,
  uuidB62,
  uuidBytes,
  uuidDecode,
  uuidDecodeB32,
  uuidDecodeB62,
  uuidDecodeV4,
  uuidEncode,
  uuidEncodeB32,
  uuidEncodeB62,
  uuidEncodeV4,
  uuidIsValid,
  uuidv4
};
//# sourceMappingURL=uuid.js.map