"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; } function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } }var _nodefs = require('node:fs');
var _nodepath = require('node:path');
var _nodeprocess = require('node:process'); var _nodeprocess2 = _interopRequireDefault(_nodeprocess);
var _fs = require('./fs');
var _glob = require('./glob');
function getStat(path) {
  try {
    return _nodefs.statSync.call(void 0, path);
  } catch (err) {
  }
}
function getFingerprint(path) {
  const { mtimeMs, size } = _nullishCoalesce(getStat(path), () => ( {}));
  return `${path}|${mtimeMs}|${size}`;
}
function walkSync(rootFolder, subFolder = "", ignoreHidden = true) {
  let resultPaths = [];
  const paths = _nodefs.readdirSync.call(void 0, _nodepath.resolve.call(void 0, rootFolder, subFolder));
  if (paths != null && paths.length > 0) {
    for (let file of paths) {
      file = _nodepath.join.call(void 0, subFolder, file);
      if (ignoreHidden && _fs.isHiddenPath.call(void 0, file))
        continue;
      const realFile = _nodepath.join.call(void 0, rootFolder, file);
      const stat = getStat(realFile);
      if (stat && stat.isDirectory())
        resultPaths = resultPaths.concat(walkSync(rootFolder, file) || []);
      else
        resultPaths.push(file);
    }
  }
  return resultPaths;
}
function files(opt = {}) {
  let {
    pattern,
    filter,
    basePath = _nodeprocess2.default.cwd(),
    ignoreHidden = false
  } = opt;
  let paths = walkSync(basePath, "", ignoreHidden);
  paths = paths.filter(
    (path) => !(ignoreHidden && (path.startsWith(".") || path.includes("/.")))
  );
  if (pattern) {
    if (typeof pattern === "string")
      pattern = _glob.globToRegExp.call(void 0, pattern);
    if (pattern instanceof RegExp) {
      const rx = pattern;
      rx.lastIndex = 0;
      paths = paths.filter((path) => rx.test(path));
    }
  }
  if (filter)
    paths = paths.filter(filter);
  return paths;
}





exports.files = files; exports.getFingerprint = getFingerprint; exports.getStat = getStat; exports.walkSync = walkSync;
//# sourceMappingURL=files.cjs.map