"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; } function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } }var _nodefs = require('node:fs');
var _nodepath = require('node:path');
var _nodebuffer = require('node:buffer');
var _nodeprocess = require('node:process'); var _nodeprocess2 = _interopRequireDefault(_nodeprocess);
var _json = require('../common/data/json');
var _path = require('../common/data/path');
var _utils = require('../common/data/utils');
class FileStorage {
  constructor(opt = {}) {
    this.store = {};
    this.fileKeys = void 0;
    this.pretty = false;
    this.dirname = _nodepath.resolve.call(void 0, _nodeprocess2.default.cwd(), _nullishCoalesce(opt.path, () => ( ".fileStorage")));
    this.pretty = !!opt.pretty;
    this.extension = _nullishCoalesce(opt.extension, () => ( ".json"));
    if (opt.extension && !this.extension.startsWith("."))
      this.extension = `.${this.extension}`;
    this.extensionLength = this.extension.length;
    this.objectToString = _nullishCoalesce(opt.objectToString, () => ( ((data) => {
      return this.pretty ? _json.jsonStringifySafe.call(void 0, data, null, 2) : _json.jsonStringifySafe.call(void 0, data);
    })));
    this.objectFromString = _nullishCoalesce(opt.objectFromString, () => ( ((data) => {
      try {
        return JSON.parse(data);
      } catch (err) {
      }
    })));
    this.keyToFilename = _nullishCoalesce(opt.keyToFilename, () => ( _path.toValidFilename));
  }
  setItem(key, value) {
    this.store[key] = _utils.cloneObject.call(void 0, value);
    try {
      const data = this.objectToString(value);
      const path = this.getPath(key);
      _nodefs.mkdirSync.call(void 0, _nodepath.dirname.call(void 0, path), { recursive: true });
      _nodefs.writeFileSync.call(void 0, path, data, "utf8");
    } catch (err) {
    }
  }
  getPath(key) {
    return _nodepath.resolve.call(void 0, this.dirname, this.keyToFilename(key) + this.extension);
  }
  getBuffer(key) {
    const path = this.getPath(key);
    return _nodebuffer.Buffer.from(_nodefs.readFileSync.call(void 0, path));
  }
  getItem(key) {
    const value = this.store[key];
    if (value === null)
      return;
    if (value != null)
      return _utils.cloneObject.call(void 0, value);
    try {
      const path = this.getPath(key);
      const data = _nodefs.readFileSync.call(void 0, path, "utf8");
      if (data != null) {
        const value2 = this.objectFromString(data);
        this.store[key] = value2;
        return value2;
      }
    } catch (err) {
      this.store[key] = null;
    }
  }
  removeItem(key) {
    delete this.store[key];
    if (this.fileKeys != null) {
      const index = this.fileKeys.indexOf(key);
      if (index !== -1)
        this.fileKeys.splice(index, 1);
    }
    try {
      const path = this.getPath(key);
      _nodefs.unlinkSync.call(void 0, path);
    } catch (err) {
    }
  }
  clear() {
    this.fileKeys = [];
    this.store = {};
    _nodefs.rmSync.call(void 0, this.dirname, { recursive: true, force: true });
  }
  allKeys() {
    if (this.fileKeys == null) {
      try {
        this.fileKeys = _nodefs.readdirSync.call(void 0, this.dirname, { withFileTypes: true }).filter(
          (item) => !item.isDirectory() && item.name.endsWith(this.extension)
        ).map((item) => item.name.slice(0, -this.extensionLength)) || [];
      } catch (err) {
      }
    }
    const keys = [...this.fileKeys || []];
    for (const key of Object.keys(this.store)) {
      if (!keys.includes(key))
        keys.push(key);
    }
    keys.sort();
    return keys;
  }
}


exports.FileStorage = FileStorage;
//# sourceMappingURL=filestorage.cjs.map