"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }var _nodefs = require('node:fs');
var _nodepath = require('node:path');
var _nodeprocess = require('node:process'); var _nodeprocess2 = _interopRequireDefault(_nodeprocess);
var _convert = require('../../common/data/convert');
var _logbase = require('../../common/log/log-base');
var _logfilter = require('../../common/log/log-filter');
const namespaces = {};
function LoggerFileHandler(path, opt = {}) {
  const {
    level = void 0,
    filter = void 0,
    time = true,
    pretty = false
  } = opt;
  path = _nodepath.resolve.call(void 0, _nodeprocess2.default.cwd(), path);
  _nodefs.mkdirSync.call(void 0, _nodepath.dirname.call(void 0, path), { recursive: true });
  const stream = _nodefs.createWriteStream.call(void 0, path, { flags: "a" });
  const matchesNamespace = _logfilter.useNamespaceFilter.call(void 0, filter);
  const matchesLevel = _logfilter.useLevelFilter.call(void 0, level);
  return (msg) => {
    if (!matchesLevel(msg.level))
      return;
    if (!matchesNamespace(msg.name))
      return;
    const timeNow = time ? `${(/* @__PURE__ */ new Date()).toISOString()} ` : "";
    const name = msg.name || "";
    const ninfo = namespaces[name || ""];
    if (ninfo == null)
      namespaces[name] = ninfo;
    const args = [
      `[${name || "*"}]`,
      _convert.renderMessages.call(void 0, msg.messages, { pretty })
    ];
    function write(...args2) {
      stream.write(`${args2.join("	")}
`);
    }
    switch (msg.level) {
      case _logbase.LogLevelInfo:
        write(`${timeNow}I|*  `, ...args);
        break;
      case _logbase.LogLevelWarn:
        write(`${timeNow}W|** `, ...args);
        break;
      case _logbase.LogLevelError:
        write(`${timeNow}E|***`, ...args);
        break;
      default:
        write(`${timeNow}D|   `, ...args);
        break;
    }
  };
}


exports.LoggerFileHandler = LoggerFileHandler;
//# sourceMappingURL=log-file.cjs.map